@@ -41,6 +41,8 @@
 
 #define KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KTEXTWIDGETS_NO_DEPRECATED) && !defined(KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54100
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54100
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KTEXTWIDGETS_DEPRECATED
-#  define KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -119,45 +121,7 @@
 #else
 #  define KTEXTWIDGETS_DEPRECATED_VERSION_5_65(text)
 #endif
-
-#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54600
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_70(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_70(text)
-#endif
-
-#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54700
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_71(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_71(text)
-#endif
-
-#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55100
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_81(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_81(text)
-#endif
-
-#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55300
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_83(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_83(text)
-#endif
-
-#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56500
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_101(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_101(text)
-#endif
 #define KTEXTWIDGETS_DEPRECATED_VERSION_5(minor, text)      KTEXTWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KTEXTWIDGETS_DEPRECATED_VERSION(major, minor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KTEXTWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KTEXTWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KTEXTWIDGETS_DEPRECATED_VERSION(major, minor, text)
-#  define KTEXTWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KTEXTWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KTEXTWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KTEXTWIDGETS_EXPORT_H */
